A Radicle node on the network is identified by its NodeId, which in turn
is a Ed25519 public key.
The human-readable format is a multibase-encoded format of the underlying Ed25519 public key, i.e.
MULTIBASE(base58-btc, MULTICODEC(public-key-type, raw-public-key-bytes))which results in strings that look like:
z6MknSLrJoTcukLrE435hVNQT4JUhbvWLX4kUzqkEStBU8ViType Aliases
- NodeId
- Public identifier of a node device in the network.